export { v4 } from 'uuid';

type TaskInput = any;
interface Artifact {
    artifact_id: string;
    agent_created: boolean;
    file_name: string;
    relative_path: string | null;
    created_at: string;
}
type StepInput = any;
type StepOutput = any;
declare enum StepStatus {
    CREATED = "created",
    RUNNING = "running",
    COMPLETED = "completed"
}
interface Step {
    name?: string;
    output?: StepOutput;
    artifacts?: Artifact[];
    is_last?: boolean;
    input?: StepInput;
    task_id: string;
    step_id: string;
    status: StepStatus;
}
interface StepRequestBody {
    input?: StepInput;
}
interface StepResult {
    name?: string;
    output?: StepOutput;
    artifacts?: Artifact[];
    is_last?: boolean;
}
interface Task {
    input?: TaskInput;
    task_id: string;
    artifacts?: Artifact[];
}
interface TaskRequestBody {
    input?: TaskInput;
}

type StepHandler = (input: StepInput | null) => Promise<StepResult>;
type TaskHandler = (taskId: string, input: TaskInput | null) => Promise<StepHandler>;
declare class StepResultWithDefaults implements StepResult {
    output?: StepOutput;
    artifacts?: Artifact[];
    is_last?: boolean;
}
declare const createAgentTask: (body: TaskRequestBody | null) => Promise<Task>;
declare const listAgentTaskIDs: () => Promise<string[]>;
declare const getAgentTask: (taskId: string) => Promise<Task>;
declare const listAgentTaskSteps: (taskId: string) => Promise<string[]>;
declare const executeAgentTaskStep: (taskId: string, body: StepRequestBody | null) => Promise<Step>;
declare const getAgentTaskStep: (taskId: string, stepId: string) => Promise<Step>;
interface AgentConfig {
    port: number;
    workspace: string;
}
declare class Agent {
    taskHandler: TaskHandler;
    config: AgentConfig;
    constructor(taskHandler: TaskHandler, config: AgentConfig);
    static handleTask(_taskHandler: TaskHandler, config: Partial<AgentConfig>): Agent;
    start(port?: number): void;
}

export { Artifact, Step, StepHandler, StepInput, StepOutput, StepRequestBody, StepResultWithDefaults as StepResult, Task, TaskHandler, TaskInput, TaskRequestBody, createAgentTask, Agent as default, executeAgentTaskStep, getAgentTask, getAgentTaskStep, listAgentTaskIDs, listAgentTaskSteps };
